@@ -22,7 +22,7 @@
 
 #include <libdolphin_export.h>
 
-#include <kitemviews/kitemlistview.h>
+#include <kitemviews/kstandarditemlistview.h>
 
 class KFileItemModelRolesUpdater;
 class QTimer;
@@ -36,18 +36,11 @@ class QTimer;
  * KItemListView::setWidgetCreator() and KItemListView::setGroupHeaderCreator()
  * to apply customized generators.
  */
-class LIBDOLPHINPRIVATE_EXPORT KFileItemListView : public KItemListView
+class LIBDOLPHINPRIVATE_EXPORT KFileItemListView : public KStandardItemListView
 {
     Q_OBJECT
 
 public:
-    enum Layout
-    {
-        IconsLayout,
-        CompactLayout,
-        DetailsLayout
-    };
-
     KFileItemListView(QGraphicsWidget* parent = 0);
     virtual ~KFileItemListView();
 
@@ -62,9 +55,6 @@ public:
     void setEnlargeSmallPreviews(bool enlarge);
     bool enlargeSmallPreviews() const;
 
-    void setItemLayout(Layout layout);
-    Layout itemLayout() const;
-
     /**
      * Sets the list of enabled thumbnail plugins that are used for previews.
      * Per default all plugins enabled in the KConfigGroup "PreviewSettings"
@@ -82,18 +72,13 @@ public:
      */
     QStringList enabledPlugins() const;
 
-    /** @reimp */
-    virtual QSizeF itemSizeHint(int index) const;
-
-    /** @reimp */
-    virtual QHash<QByteArray, QSizeF> visibleRolesSizes(const KItemRangeList& itemRanges) const;
-
     /** @reimp */
     virtual QPixmap createDragPixmap(const QSet<int>& indexes) const;
 
 protected:
-    virtual void initializeItemListWidget(KItemListWidget* item);
-    virtual bool itemSizeHintUpdateRequired(const QSet<QByteArray>& changedRoles) const;
+    virtual KItemListWidgetCreatorBase* defaultWidgetCreator() const;
+    virtual void onPreviewsShownChanged(bool shown);
+    virtual void onItemLayoutChanged(ItemLayout current, ItemLayout previous);
     virtual void onModelChanged(KItemModelBase* current, KItemModelBase* previous);
     virtual void onScrollOrientationChanged(Qt::Orientation current, Qt::Orientation previous);
     virtual void onItemSizeChanged(const QSizeF& current, const QSizeF& previous);
@@ -117,10 +102,7 @@ private slots:
     void updateIconSize();
 
 private:
-    QSizeF visibleRoleSizeHint(int index, const QByteArray& role) const;
-    void updateLayoutOfVisibleItems();
     void updateTimersInterval();
-    void updateMinimumRolesWidths();
 
     /**
      * Applies the roles defined by KItemListView::visibleRoles() to the
@@ -138,15 +120,10 @@ private:
     QSize availableIconSize() const;
 
 private:
-    Layout m_itemLayout;
-
     KFileItemModelRolesUpdater* m_modelRolesUpdater;
     QTimer* m_updateVisibleIndexRangeTimer;
     QTimer* m_updateIconSizeTimer;
 
-    // Cache for calculating visibleRoleSizes() in a fast way
-    QHash<QByteArray, int> m_minimumRolesWidths;
-
     friend class KFileItemListViewTest; // For unit testing
 };
 
