@@ -29,6 +29,11 @@
 #include "kitemviews/private/kitemlistviewlayouter.h"
 #include "testdir.h"
 
+#include <KConfigGroup>
+#include <KGlobalSettings>
+
+#include <QGraphicsSceneMouseEvent>
+
 namespace {
     const int DefaultTimeout = 2000;
 };
@@ -51,6 +56,7 @@ private slots:
 
     void testKeyboardNavigation_data();
     void testKeyboardNavigation();
+    void testMouseClickActivation();
 
 private:
     /**
@@ -506,6 +512,141 @@ void KItemListControllerTest::testKeyboardNavigation()
     }
 }
 
+void KItemListControllerTest::testMouseClickActivation()
+{
+    m_view->setItemLayout(KFileItemListView::IconsLayout);
+
+    // Make sure that we have a large window, such that
+    // the items are visible and clickable.
+    adjustGeometryForColumnCount(5);
+
+    // Make sure that the first item is visible in the view.
+    m_view->setScrollOffset(0);
+    QCOMPARE(m_view->firstVisibleIndex(), 0);
+
+    const QPointF pos = m_view->itemContextRect(0).center();
+
+    // Save the "single click" setting.
+    const bool restoreKGlobalSettingsSingleClick = KGlobalSettings::singleClick();
+
+    KConfig config("kcminputrc");
+    KConfigGroup group = config.group("KDE");
+
+    QGraphicsSceneMouseEvent mousePressEvent(QEvent::GraphicsSceneMousePress);
+    mousePressEvent.setPos(pos);
+    mousePressEvent.setButton(Qt::LeftButton);
+    mousePressEvent.setButtons(Qt::LeftButton);
+
+    QGraphicsSceneMouseEvent mouseReleaseEvent(QEvent::GraphicsSceneMouseRelease);
+    mouseReleaseEvent.setPos(pos);
+    mouseReleaseEvent.setButton(Qt::LeftButton);
+    mouseReleaseEvent.setButtons(Qt::NoButton);
+
+    QSignalSpy spyItemActivated(m_controller, SIGNAL(itemActivated(int)));
+
+    // Default setting: single click activation.
+    group.writeEntry("SingleClick", true, KConfig::Persistent|KConfig::Global);
+    config.sync();
+    KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged, KGlobalSettings::SETTINGS_MOUSE);
+
+    int iterations = 0;
+    const int maxIterations = 20;
+    while (!KGlobalSettings::singleClick() && iterations < maxIterations) {
+        QTest::qWait(50);
+        ++iterations;
+    }
+
+    if (!KGlobalSettings::singleClick()) {
+        // TODO: Try to find a way to make sure that changing the global setting works.
+        QSKIP("Failed to change the KGlobalSettings::singleClick() setting!", SkipSingle);
+    }
+
+    m_view->event(&mousePressEvent);
+    m_view->event(&mouseReleaseEvent);
+    QCOMPARE(spyItemActivated.count(), 1);
+    spyItemActivated.clear();
+
+    // Set the global setting to "double click activation".
+    group.writeEntry("SingleClick", false, KConfig::Persistent|KConfig::Global);
+    config.sync();
+    KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged, KGlobalSettings::SETTINGS_MOUSE);
+
+    iterations = 0;
+    while (KGlobalSettings::singleClick() && iterations < maxIterations) {
+        QTest::qWait(50);
+        ++iterations;
+    }
+
+    if (KGlobalSettings::singleClick()) {
+        // TODO: Try to find a way to make sure that changing the global setting works.
+        QSKIP("Failed to change the KGlobalSettings::singleClick() setting!", SkipSingle);
+    }
+
+    m_view->event(&mousePressEvent);
+    m_view->event(&mouseReleaseEvent);
+    QCOMPARE(spyItemActivated.count(), 0);
+    spyItemActivated.clear();
+
+    // Enforce single click activation in the controller.
+    m_controller->setSingleClickActivationEnforced(true);
+    m_view->event(&mousePressEvent);
+    m_view->event(&mouseReleaseEvent);
+    QCOMPARE(spyItemActivated.count(), 1);
+    spyItemActivated.clear();
+
+    // Do not enforce single click activation in the controller.
+    m_controller->setSingleClickActivationEnforced(false);
+    m_view->event(&mousePressEvent);
+    m_view->event(&mouseReleaseEvent);
+    QCOMPARE(spyItemActivated.count(), 0);
+    spyItemActivated.clear();
+
+    // Set the global setting back to "single click activation".
+    group.writeEntry("SingleClick", true, KConfig::Persistent|KConfig::Global);
+    config.sync();
+    KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged, KGlobalSettings::SETTINGS_MOUSE);
+
+    iterations = 0;
+    while (!KGlobalSettings::singleClick() && iterations < maxIterations) {
+        QTest::qWait(50);
+        ++iterations;
+    }
+
+    if (!KGlobalSettings::singleClick()) {
+        // TODO: Try to find a way to make sure that changing the global setting works.
+        QSKIP("Failed to change the KGlobalSettings::singleClick() setting!", SkipSingle);
+    }
+
+    m_view->event(&mousePressEvent);
+    m_view->event(&mouseReleaseEvent);
+    QCOMPARE(spyItemActivated.count(), 1);
+    spyItemActivated.clear();
+
+    // Enforce single click activation in the controller.
+    m_controller->setSingleClickActivationEnforced(true);
+    m_view->event(&mousePressEvent);
+    m_view->event(&mouseReleaseEvent);
+    QCOMPARE(spyItemActivated.count(), 1);
+    spyItemActivated.clear();
+
+    // Restore previous settings.
+    m_controller->setSingleClickActivationEnforced(true);
+    group.writeEntry("SingleClick", restoreKGlobalSettingsSingleClick, KConfig::Persistent|KConfig::Global);
+    config.sync();
+    KGlobalSettings::self()->emitChange(KGlobalSettings::SettingsChanged, KGlobalSettings::SETTINGS_MOUSE);
+    
+    iterations = 0;
+    while (KGlobalSettings::singleClick() != restoreKGlobalSettingsSingleClick && iterations < maxIterations) {
+        QTest::qWait(50);
+        ++iterations;
+    }
+
+    if (KGlobalSettings::singleClick() != restoreKGlobalSettingsSingleClick) {
+        // TODO: Try to find a way to make sure that changing the global setting works.
+        QSKIP("Failed to change the KGlobalSettings::singleClick() setting!", SkipSingle);
+    }
+}
+
 void KItemListControllerTest::adjustGeometryForColumnCount(int count)
 {
     const QSize size = m_view->itemSize().toSize();
