@@ -463,7 +463,7 @@ void FolderView::init()
 
 void FolderView::networkAvailable()
 {
-    if (KProtocolInfo::protocolClass(m_url.protocol()) == ":local") {
+    if (KProtocolInfo::protocolClass(m_url.protocol()) != ":local") {
         m_dirLister->openUrl(m_url);
     }
 }
@@ -554,7 +554,7 @@ void FolderView::configChanged()
 
     const int sortColumn = cg.readEntry("sortColumn", m_sortColumn);
     const Qt::SortOrder sortOrder = sortOrderStringToEnum(cg.readEntry("sortOrder", sortOrderEnumToString(m_sortOrder)));
-    if ((m_sortColumn != sortColumn) || (m_sortOrder != m_sortOrder)) {
+    if ((m_sortColumn != sortColumn) || (m_sortOrder != sortOrder)) {
         m_sortColumn = sortColumn;
         m_sortOrder = sortOrder;
         if (m_sortColumn != -1) {
@@ -2140,8 +2140,12 @@ QSizeF FolderView::sizeHint(Qt::SizeHint which, const QSizeF &constraint) const
               break;
           case Plasma::Horizontal:
           case Plasma::Vertical:
-              const int iconSize = IconSize(KIconLoader::Panel);
-              size = QSizeF(iconSize, iconSize);
+                {
+                    const int iconSize = IconSize(KIconLoader::Panel);
+                    size = QSizeF(iconSize, iconSize);
+                    break;
+                }
+          default:
               break;
         }
 
